==> netbeans_6.1.orig.tar.gz: netbeans-6.1/j2ee.core.utilities/test/unit/src/org/netbeans/modules/j2ee/core/api/support/java/JavaIdentifiersTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 * 
 * Contributor(s):
 * 
 * Portions Copyrighted 2007 Sun Microsystems, Inc.
 */

package org.netbeans.modules.j2ee.core.api.support.java;

import junit.framework.TestCase;

/**
 *
 * @author Erno Mononen
 */
public class JavaIdentifiersTest extends TestCase {

    public JavaIdentifiersTest(String testName) {
        super(testName);
    }

    public void testIsValidPackageName() {
        assertTrue(JavaIdentifiers.isValidPackageName(""));
        assertTrue(JavaIdentifiers.isValidPackageName("foo"));
        assertTrue(JavaIdentifiers.isValidPackageName("foo.bar"));
        assertTrue(JavaIdentifiers.isValidPackageName("fooBar"));

        assertFalse(JavaIdentifiers.isValidPackageName(".foo"));
        assertFalse(JavaIdentifiers.isValidPackageName("foo-bar"));
        assertFalse(JavaIdentifiers.isValidPackageName("."));
        assertFalse(JavaIdentifiers.isValidPackageName(".foo"));
        assertFalse(JavaIdentifiers.isValidPackageName("foo.bar."));
        assertFalse(JavaIdentifiers.isValidPackageName("foo. .bar"));
        assertFalse(JavaIdentifiers.isValidPackageName(" "));
        assertFalse(JavaIdentifiers.isValidPackageName("public"));
        assertFalse(JavaIdentifiers.isValidPackageName("int"));
    }

    public void testUnqualify() {
        assertEquals("Foo", JavaIdentifiers.unqualify("Foo"));
        assertEquals("Baz", JavaIdentifiers.unqualify("foo.bar.Baz"));
        assertInvalidFQN("foo.");
        assertInvalidFQN(".");
        assertInvalidFQN(".foo.");
        assertInvalidFQN(".foo.Bar");
    }

    private void assertInvalidFQN(String fqn) {
        try {
            JavaIdentifiers.unqualify(fqn);
            fail();
        } catch (IllegalArgumentException expected) {
        }
    }

    public void testGetPackageName() {
        assertEquals("", JavaIdentifiers.getPackageName("Bop"));
        assertEquals("foo.bar.baz", JavaIdentifiers.getPackageName("foo.bar.baz.Bop"));
        try {
            JavaIdentifiers.getPackageName("foo.bar.");
            fail();
        } catch (IllegalArgumentException expected) {
        }
    }
}

==> netbeans_6.7.1.orig.tar.gz: netbeans-6.7.1/j2ee.core.utilities/test/unit/src/org/netbeans/modules/j2ee/core/api/support/java/JavaIdentifiersTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 * 
 * Contributor(s):
 * 
 * Portions Copyrighted 2007 Sun Microsystems, Inc.
 */

package org.netbeans.modules.j2ee.core.api.support.java;

import junit.framework.TestCase;

/**
 *
 * @author Erno Mononen
 */
public class JavaIdentifiersTest extends TestCase {

    public JavaIdentifiersTest(String testName) {
        super(testName);
    }

    public void testIsValidPackageName() {
        assertTrue(JavaIdentifiers.isValidPackageName(""));
        assertTrue(JavaIdentifiers.isValidPackageName("foo"));
        assertTrue(JavaIdentifiers.isValidPackageName("foo.bar"));
        assertTrue(JavaIdentifiers.isValidPackageName("fooBar"));

        assertFalse(JavaIdentifiers.isValidPackageName(".foo"));
        assertFalse(JavaIdentifiers.isValidPackageName("foo-bar"));
        assertFalse(JavaIdentifiers.isValidPackageName("."));
        assertFalse(JavaIdentifiers.isValidPackageName(".foo"));
        assertFalse(JavaIdentifiers.isValidPackageName("foo.bar."));
        assertFalse(JavaIdentifiers.isValidPackageName("foo. .bar"));
        assertFalse(JavaIdentifiers.isValidPackageName(" "));
        assertFalse(JavaIdentifiers.isValidPackageName("public"));
        assertFalse(JavaIdentifiers.isValidPackageName("int"));
        assertFalse(JavaIdentifiers.isValidPackageName("java"));
        assertFalse(JavaIdentifiers.isValidPackageName("java.something"));
    }

    public void testUnqualify() {
        assertEquals("Foo", JavaIdentifiers.unqualify("Foo"));
        assertEquals("Baz", JavaIdentifiers.unqualify("foo.bar.Baz"));
        assertInvalidFQN("foo.");
        assertInvalidFQN(".");
        assertInvalidFQN(".foo.");
        assertInvalidFQN(".foo.Bar");
    }

    private void assertInvalidFQN(String fqn) {
        try {
            JavaIdentifiers.unqualify(fqn);
            fail();
        } catch (IllegalArgumentException expected) {
        }
    }

    public void testGetPackageName() {
        assertEquals("", JavaIdentifiers.getPackageName("Bop"));
        assertEquals("foo.bar.baz", JavaIdentifiers.getPackageName("foo.bar.baz.Bop"));
        try {
            JavaIdentifiers.getPackageName("foo.bar.");
            fail();
        } catch (IllegalArgumentException expected) {
        }
    }
}
